@@ -214,6 +214,7 @@ pub enum SyntaxError {
     TS1196,
     TS1242,
     TS1243(JsWord, JsWord),
+    TS1383,
     TS2206,
     TS2207,
     TS2369,
@@ -528,6 +529,7 @@ impl SyntaxError {
                 left, right
             )
             .into(),
+            SyntaxError::TS1383 => "Only named exports may use 'export type'.".into(),
             SyntaxError::TS2206 => "The 'type' modifier cannot be used on a named import when \
                                     'import type' is used on its import statement."
                 .into(),
