@@ -65,13 +65,25 @@ impl<'a, I: Tokens> Parser<I> {
                 },
                 _ => unreachable!(),
             };
+            let _ = cur!(self, false);
+            let asserts = if self.input.syntax().import_assertions()
+                && !self.input.had_line_break_before_cur()
+                && eat!(self, "assert")
+            {
+                match *self.parse_object::<Box<Expr>>()? {
+                    Expr::Object(v) => Some(v),
+                    _ => unreachable!(),
+                }
+            } else {
+                None
+            };
             expect!(self, ';');
             return Ok(ModuleDecl::Import(ImportDecl {
                 span: span!(self, start),
                 src,
                 specifiers: vec![],
                 type_only: false,
-                asserts: None,
+                asserts,
             }))
             .map(ModuleItem::from);
         }
@@ -393,6 +405,12 @@ impl<'a, I: Tokens> Parser<I> {
 
         if eat!(self, '*') {
             has_star = true;
+            if self.input.syntax().typescript() && type_only {
+                // export type * from "mod";
+                // or
+                // export type * as foo from "mod";
+                self.emit_err(span!(self, start), SyntaxError::TS1383)
+            }
             if is!(self, "from") {
                 let (src, asserts) = self.parse_from_clause_and_semi()?;
                 return Ok(ModuleDecl::ExportAll(ExportAll {
